VmServiceExtensionException class final Getting Started

Thrown when an ext.basalt.* VM service extension call fails.

Implemented types

Constructors

VmServiceExtensionException(String message, {int? errorCode, String? stackTrace})
Creates the exception with a message and optional diagnostics.

Properties

errorCode int?
VM service RPC error code, when the failure came from an RPCError.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable description of the failure.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace String?
Server-side stack trace, when one was reported.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited